import config from '@/config'
import storage from '@/utils/storage'
import constant from '@/utils/constant'
import {
	login,
	logout,
	getInfo
} from '@/api/login'
import {
	getToken,
	setToken,
	removeToken,
	setServerUrl,
	setUserGuid,
	getAdminType,
	setAdminType,
	removeAdminType
} from '@/utils/auth'

const baseUrl = config.baseUrl

const user = {
	state: {
		token: getToken(),
		name: storage.get(constant.name),
		avatar: storage.get(constant.avatar),
		roles: storage.get(constant.roles),
		permissions: storage.get(constant.permissions),
		adminType: getAdminType(),
	},

	mutations: {
		SET_TOKEN: (state, token) => {
			state.token = token
		},
		SET_NAME: (state, name) => {
			state.name = name
			storage.set(constant.name, name)
		},
		SET_AVATAR: (state, avatar) => {
			state.avatar = avatar
			storage.set(constant.avatar, avatar)
		},
		SET_ROLES: (state, roles) => {
			state.roles = roles
			storage.set(constant.roles, roles)
		},
		SET_PERMISSIONS: (state, permissions) => {
			state.permissions = permissions
			storage.set(constant.permissions, permissions)
		},
		SET_ADMINTYPE: (state, adminType) => {
			state.adminType = adminType
		}
	},

	actions: {
		// 登录
		Login({
			commit
		}, userInfo) {
			console.log(userInfo)
			const acctID = userInfo.acctID
			const username = userInfo.username.trim()
			const password = userInfo.password
			const lcid = userInfo.lcid
			
			return new Promise((resolve, reject) => {
				login(acctID,username, password, lcid).then(res => {
					console.log(res, 'asfasfasf')
					if (res.LoginResultType == "1") {
						setToken(res.Context.UserToken)
						// setServerUrl(FacadeName)
						// setUserGuid(res.Result.UserGuid)
						console.log("aaaaaaaaa"+res.Context.Username)
						uni.setStorageSync('username', res.Context.Username)
						commit('SET_TOKEN', res.Context.SessionId)
						resolve()
					} else {
						reject(res.Message)
						return
					}
				}).catch(error => {
					console.log(error)
					reject(error)
				})
			})
		},

		// 获取用户信息
		GetInfo({
			commit,
			state
		}) {
			return new Promise((resolve, reject) => {
				getInfo().then(res => {
					const user = res.data
					// const avatar = ""//(user == null || user.avatar == "" || user.avatar == null) ? require("@/static/images/profile.jpg") : baseUrl + user.avatar
					// const UserName = (user == null || user.userName == "" || user.userName == null) ? "" : user.userName
					// if (res.roles && res.roles.length > 0) {
					//   commit('SET_ROLES', res.roles)
					//   commit('SET_PERMISSIONS', res.permissions)
					// } else {
					//   commit('SET_ROLES', ['ROLE_DEFAULT'])
					// }
					// commit('SET_NAME', UserName)
					// commit('SET_AVATAR', avatar)
					setAdminType(user.adminType)
					commit('SET_ADMINTYPE', user.adminType)
					resolve(res)
				}).catch(error => {
					reject(error)
				})
			})
		},

		// 退出系统
		LogOut({
			commit,
			state
		}) {
			return new Promise((resolve, reject) => {
				logout(state.token).then(() => {
					commit('SET_TOKEN', '')
					commit('SET_ROLES', [])
					commit('SET_PERMISSIONS', [])
					removeToken()
					removeAdminType()
					storage.clean()
					resolve()
				}).catch(error => {
					reject(error)
				})
			})
		}
	}
}

export default user